@@ -9,19 +9,25 @@ Utilities to execute code blocks in Markdown files.
 
 from __future__ import annotations
 
+import re
 from typing import Any
 
 from markdown import Markdown
 
-from markdown_exec.python import exec_python
+from markdown_exec.pycon import format_pycon
+from markdown_exec.python import format_python
 
 __all__: list[str] = ["formatter", "validator"]  # noqa: WPS410
 
 
 _formatters = {
-    "python": exec_python,
+    "python": format_python,
+    "pycon": format_pycon,
 }
 
+# negative look behind: matches only if | (pipe) if not preceded by \ (backslash)
+_tabs_re = re.compile(r"(?<!\\)\|")
+
 
 def validator(
     language: str, inputs: dict[str, str], options: dict[str, Any], attrs: dict[str, Any], md: Markdown
@@ -41,9 +47,15 @@ def validator(
     exec_value = _to_bool(inputs.pop("exec", "no"))
     if not exec_value:
         return False
-    isolate_value = _to_bool(inputs.pop("isolate", "no"))
+    html_value = _to_bool(inputs.pop("html", "no"))
+    source_value = inputs.pop("source", "")
+    tabs_value = inputs.pop("tabs", "Source|Result")
+    tabs = tuple(_tabs_re.split(tabs_value, maxsplit=1))
     options["exec"] = exec_value
-    options["isolate"] = isolate_value
+    options["html"] = html_value
+    options["source"] = source_value
+    options["tabs"] = tabs
+    options["extra"] = inputs
     return True
 
 
@@ -56,7 +68,7 @@ def formatter(
     classes: list[str] | None = None,
     id_value: str = "",
     attrs: dict[str, Any] | None = None,
-    **kwargs,
+    **kwargs: Any,
 ) -> str:
     """Execute code and return HTML.
 
@@ -76,8 +88,20 @@ def formatter(
         HTML contents.
     """
     fmt = _formatters.get(language, lambda source, *args, **kwargs: source)
-    return fmt(source, md)
+    return fmt(source, md, **options)
 
 
-def _to_bool(value):
-    return value.lower() not in {"", "no", "off", "false", "0"}
+falsy_values = {"", "no", "off", "false", "0"}
+truthy_values = {"yes", "on", "true", "1"}
+
+
+def _to_bool(value: str) -> bool:
+    return value.lower() not in falsy_values
+
+
+def _to_bool_or_value(value: str) -> bool | str:
+    if value.lower() in falsy_values:
+        return False
+    if value.lower() in truthy_values:
+        return True
+    return value
